# Generated by Django 4.2.6 on 2023-10-07 09:55

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("cjkcms", "0015_eventcalendar"),
    ]

    operations = [
        migrations.AddField(
            model_name="layoutsettings",
            name="breadcrumb_icon",
            field=models.CharField(
                blank=True,
                default="slash",
                help_text="Bootstrap icon name. See docs for built-in options.",
                max_length=32,
                verbose_name="Breadcrumb icon",
            ),
        ),
        migrations.AddField(
            model_name="layoutsettings",
            name="breadcrumbs",
            field=models.BooleanField(
                default=False,
                help_text="Show breadcrumbs in page header",
                verbose_name="Breadcrumbs",
            ),
        ),
    ]
