{% load cjkcms_tags django_bootstrap5 i18n %}
      <form action="{% url 'cjkcms_search' %}" method="GET">
        {% csrf_token %}
        {% get_searchform request as form %}
        {% bootstrap_form form layout='inline' %}
    </form>